import { useLogin } from '@/services/demo/UserController';
import { AesEncode } from '@/utils/crypto';
import { LockOutlined, UserOutlined } from '@ant-design/icons';
import { Button, Divider, Flex, Form, Input, message } from 'antd';
import md5 from 'js-md5';
import React, { useState } from 'react';
import style from './index.less';

type FieldType = {
    username: string;
    password: string;
};

const ValidateCodeForm: React.FC = () => {
    const [messageVisible, setMessageVisible] = useState<boolean>(false);
    const sendSmsCode = () => {
        message.success('发送短信验证码成功');
    };

    return (
        <Flex justify="center" align="center">
            <Input.Search
                placeholder="请输入短信验证码"
                allowClear
                enterButton="发送短信验证码"
                size="large"
                onSearch={sendSmsCode}
            />
        </Flex>
    );
};

const LoginPage: React.FC = () => {
    const [form] = Form.useForm();
    const fillForms = () => {
        form.setFieldsValue({ username: '嘻嘻嘻', password: '123' });
    };

    const [passwordVisible, setPasswordVisible] = React.useState(false);

    const useLoginDeep = async () => {
        const a = await useLogin({
            username: AesEncode(form.getFieldValue('username')),
            // username: form.getFieldValue('username'),
            password: AesEncode(
                md5(form.getFieldValue('password')).toUpperCase(),
            ),
        });

        console.log('登录结果', a);
    };
    return (
        <Flex className={style.container} align="center" justify="center">
            <Flex
                align="center"
                justify="center"
                vertical
                style={{ width: '400px', height: '100vh' }}
            >
                <ValidateCodeForm />
                <div className={style.title}>惠融易客商户后台</div>
                <Divider />
                <Form
                    form={form}
                    name="login"
                    style={{ maxWidth: 600, width: '100%' }}
                    initialValues={{ remember: true }}
                >
                    <Form.Item<FieldType> name="username">
                        <Input
                            size="large"
                            prefix={
                                <UserOutlined
                                    style={{ color: 'rgba(0, 0, 0, 0.25)' }}
                                />
                            }
                            placeholder="Please input username"
                            allowClear
                        />
                    </Form.Item>

                    <Form.Item<FieldType> name="password">
                        <Input.Password
                            size="large"
                            prefix={
                                <LockOutlined
                                    style={{ color: 'rgba(0, 0, 0, 0.25)' }}
                                />
                            }
                            placeholder="Please input password"
                            allowClear
                        />
                    </Form.Item>

                    <Button
                        type="primary"
                        size="large"
                        block
                        onClick={useLoginDeep}
                    >
                        Login
                    </Button>
                </Form>
            </Flex>
        </Flex>
    );
};

export default LoginPage;
